@@ -1,4 +1,4 @@
-from time import time, strftime, localtime, mktime
+from time import time, strftime, localtime
 from pytz import utc, timezone
 from json import dumps
 from celery import Task
@@ -26,11 +26,11 @@ def record_start_datetime(func):
     Decorator: record task start time
     """
     def _inner(*args, **kwargs):
-        date_start = time()
-        date = strftime('%Y%m%d', localtime())
+        date_start_timestamp = time()
+        date = strftime('%Y-%m-%d', localtime(date_start_timestamp))
         _result = func(*args, **kwargs)
         task_id = _result.task_id
-        _data = dumps({"date_start": date_start, "task_id": task_id})
+        _data = dumps({"date_start": date_start_timestamp, "task_id": task_id})
         redis_connection = Redis(connection_pool=REDIS_CONNECTION_POOL)
         redis_connection.set(f'{date}/{task_id}', _data, ex=REDIS_RECORD_TTL)
         return _result
@@ -175,6 +175,7 @@ class CustomTask(Task):
             CONSUL_SECRETS.get('SNOOPY_CORPSECRET', 'bT2XAXzTiPadNw')
         )
         result = TaskResult.objects.filter(task_id=task_id, ).first()
+        # Convert utc datetime to local strftime
         utc_to_local_strftime = lambda utc_datetime: utc_datetime.replace(
             tzinfo=utc).astimezone(timezone(settings.TIME_ZONE)).strftime("%Y-%m-%d %H:%M:%S")
         message = dumps({
@@ -183,4 +184,4 @@ class CustomTask(Task):
             "task_id": task_id,
         })
         send_to = CONSUL_SECRETS.get('TASK_FAILURE_SENDTO', 'huaxingliu@yangqianguan.com')
-        snoopy.error(send_to, message)
+        snoopy.error(send_to=send_to, message=message)
