@@ -15,10 +15,17 @@ Including another URLconf
 """
 
 from django.urls import path
+from django_opstasks.views import (
+    dashboard_task_in_queues,
+    dashboard_task_execution_trend,
+    dashboard_queue_workers_in_queue,
+    dashboard_queue_tasks_exe_count_in_queue,
+)
 
-from django_opstasks.views import error_test, sync_task_to_database
 
 urlpatterns = [
-    path('error', error_test),
-    path('database', sync_task_to_database),
+    path('dashboard/task/in_queues', dashboard_task_in_queues),
+    path('dashboard/task/execution_trend', dashboard_task_execution_trend),
+    path('dashboard/queue/workers_in_queue', dashboard_queue_workers_in_queue),
+    path('dashboard/queue/tasks_exe_count_in_queue', dashboard_queue_tasks_exe_count_in_queue),
 ]
